From: Carsten Langgaard <carstenl@mips.com>
To: Ralf Baechle <ralf@oss.sgi.com>,
"linux-mips@oss.sgi.com" <linux-mips@oss.sgi.com>
Subject: LTP testing
Date: Tue, 25 Jun 2002 12:47:54 +0200 [thread overview]
Message-ID: <3D184A59.E755154B@mips.com> (raw)
[-- Attachment #1: Type: text/plain, Size: 508 bytes --]
The next LTP failure is:
msync05 1 FAIL : msync() fails, unexpected errno:14, expected:
ENOMEM
This has also been fixed in the 2.4.19-pre4 patch.
See the attached patch below.
/Carsten
--
_ _ ____ ___ Carsten Langgaard Mailto:carstenl@mips.com
|\ /|||___)(___ MIPS Denmark Direct: +45 4486 5527
| \/ ||| ____) Lautrupvang 4B Switch: +45 4486 5555
TECHNOLOGIES 2750 Ballerup Fax...: +45 4486 5556
Denmark http://www.mips.com
[-- Attachment #2: filemap.patch --]
[-- Type: text/plain, Size: 902 bytes --]
Index: mm/filemap.c
===================================================================
RCS file: /home/repository/sw/linux-2.4.18/mm/filemap.c,v
retrieving revision 1.1.1.1
diff -u -r1.1.1.1 filemap.c
--- mm/filemap.c 4 Mar 2002 11:13:34 -0000 1.1.1.1
+++ mm/filemap.c 25 Jun 2002 10:36:12 -0000
@@ -2179,18 +2179,18 @@
goto out;
/*
* If the interval [start,end) covers some unmapped address ranges,
* just ignore them, but return -EFAULT at the end.
*/
vma = find_vma(current->mm, start);
unmapped_error = 0;
for (;;) {
/* Still start < end. */
- error = -EFAULT;
+ error = -ENOMEM;
if (!vma)
goto out;
/* Here start < vma->vm_end. */
if (start < vma->vm_start) {
- unmapped_error = -EFAULT;
+ unmapped_error = -ENOMEM;
start = vma->vm_start;
}
/* Here vma->vm_start <= start < vma->vm_end. */
next reply other threads:[~2002-06-25 10:44 UTC|newest]
Thread overview: 13+ messages / expand[flat|nested] mbox.gz Atom feed top
2002-06-25 10:47 Carsten Langgaard [this message]
-- strict thread matches above, loose matches on Subject: below --
2002-06-25 13:21 LTP testing Carsten Langgaard
2002-06-25 13:53 ` Maciej W. Rozycki
2002-06-25 14:18 ` Carsten Langgaard
2002-06-25 14:56 ` Maciej W. Rozycki
2002-06-25 15:06 ` Carsten Langgaard
2002-06-25 15:28 ` Ralf Baechle
2002-06-25 14:28 ` Johannes Stezenbach
2002-06-25 14:39 ` Ralf Baechle
2002-06-25 9:59 Carsten Langgaard
2002-06-25 12:07 ` Maciej W. Rozycki
2002-06-25 7:15 Carsten Langgaard
2002-06-25 13:59 ` Ralf Baechle
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=3D184A59.E755154B@mips.com \
--to=carstenl@mips.com \
--cc=linux-mips@oss.sgi.com \
--cc=ralf@oss.sgi.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -2179,18 +2179,18 @@
/*
* If the interval [start,end) covers some unmapped address ranges,
- * just ignore them, but return -EFAULT at the end.
+ * just ignore them, but return -ENOMEM at the end.
*/
vma = find_vma(current->mm, start);
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox